.. _sampling_collection:

Random and low-discrepency samples
==================================

.. currentmodule:: chaospy

Generator function
------------------

.. autosummary::
    :toctree: ../api

    generate_samples

.. _low_discrepancy_sequences:

Low-discrepancy sequences
-------------------------

.. autosummary::
    :toctree: ../api

    create_halton_samples
    create_hammersley_samples
    create_korobov_samples
    create_sobol_samples
    create_latin_hypercube_samples
    create_grid_samples
    create_chebyshev_samples

Antithetic Variates
-------------------

.. autosummary::
    :toctree: ../api

    create_antithetic_variates
